# "testpypiMP" - My Simple Project

* Opt1
* Opt2
* Opt3

## Install

```python
pip install testpypiMP
```

### Usage

``` python
from testpypiMP.m_mod_mp import name as n
from testpypiMP.m_mod_mp import get_numpy_arr
>>> n("Name", "Surname")
Name Surname
>>> get_numpy_arr([1, 2, 3, 4, 5])
[1 2 3 4 5
```
